@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 import proto  # type: ignore
 
 __protobuf__ = proto.module(
@@ -36,14 +38,15 @@ class RawDocument(proto.Message):
             Inline document content.
         mime_type (str):
             An IANA MIME type (RFC6838) indicating the nature and format
-            of the [content].
+            of the
+            [content][google.cloud.documentai.v1beta3.RawDocument.content].
     """
 
-    content = proto.Field(
+    content: bytes = proto.Field(
         proto.BYTES,
         number=1,
     )
-    mime_type = proto.Field(
+    mime_type: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -59,11 +62,11 @@ class GcsDocument(proto.Message):
             An IANA MIME type (RFC6838) of the content.
     """
 
-    gcs_uri = proto.Field(
+    gcs_uri: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    mime_type = proto.Field(
+    mime_type: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -73,11 +76,11 @@ class GcsDocuments(proto.Message):
     r"""Specifies a set of documents on Cloud Storage.
 
     Attributes:
-        documents (Sequence[google.cloud.documentai_v1beta3.types.GcsDocument]):
+        documents (MutableSequence[google.cloud.documentai_v1beta3.types.GcsDocument]):
             The list of documents.
     """
 
-    documents = proto.RepeatedField(
+    documents: MutableSequence["GcsDocument"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="GcsDocument",
@@ -93,7 +96,7 @@ class GcsPrefix(proto.Message):
             The URI prefix.
     """
 
-    gcs_uri_prefix = proto.Field(
+    gcs_uri_prefix: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -113,7 +116,7 @@ class BatchDocumentsInputConfig(proto.Message):
     Attributes:
         gcs_prefix (google.cloud.documentai_v1beta3.types.GcsPrefix):
             The set of documents that match the specified Cloud Storage
-            [gcs_prefix].
+            ``gcs_prefix``.
 
             This field is a member of `oneof`_ ``source``.
         gcs_documents (google.cloud.documentai_v1beta3.types.GcsDocuments):
@@ -123,13 +126,13 @@ class BatchDocumentsInputConfig(proto.Message):
             This field is a member of `oneof`_ ``source``.
     """
 
-    gcs_prefix = proto.Field(
+    gcs_prefix: "GcsPrefix" = proto.Field(
         proto.MESSAGE,
         number=1,
         oneof="source",
         message="GcsPrefix",
     )
-    gcs_documents = proto.Field(
+    gcs_documents: "GcsDocuments" = proto.Field(
         proto.MESSAGE,
         number=2,
         oneof="source",
@@ -161,12 +164,12 @@ class DocumentOutputConfig(proto.Message):
                 output.
         """
 
-        gcs_uri = proto.Field(
+        gcs_uri: str = proto.Field(
             proto.STRING,
             number=1,
         )
 
-    gcs_output_config = proto.Field(
+    gcs_output_config: GcsOutputConfig = proto.Field(
         proto.MESSAGE,
         number=1,
         oneof="destination",
